@@ -15,7 +15,7 @@
 # where one assumes all items presented to all persons.
 #
 # Licensed under the GNU General Public License Version 3 (June 2007)
-# copyright (c) 2021, Last Modified 25/10/2021
+# copyright (c) 2021, Last Modified 2/9/2024
 ######################################################################
 #' Power analysis of tests of invariance of item parameters between two groups
 #' of persons in partial credit model
@@ -121,18 +121,18 @@
 #'\eqn{Var(P)} is then used to quantify the random error of the suggested Monte Carlo computation
 #'procedure. It is called Monte Carlo error of power.
 #'
-#' @param alpha Probability of error of first kind.
 #' @param n_total Total sample size for which power shall be determined.
+#' @param local_dev A list consisting of two lists. One list refers to group 1, the other to group 2.
+#' Each of the two lists contains a numeric vector per item, i.e., each list contains as many vectors as items.
+#' Each vector contains the free item-cat. parameters of the respective item. The number of free item-cat.
+#' parameters per item equals the number of categories of the item minus 1.
+#' @param alpha Probability of error of first kind.
 #' @param persons1 A vector of person parameters in group 1 (drawn from a specified distribution).
 #' By default \eqn{10^6} parameters are drawn at random from the standard normal distribution. The larger
 #' this number the more accurate are the computations. See Details.
 #' @param persons2 A vector of person parameters in group 2 (drawn from a specified distribution).
 #' By default \eqn{10^6} parameters are drawn at random from the standard normal distribution. The larger
 #' this number the more accurate are the computations. See Details.
-#' @param local_dev A list consisting of two lists. One list refers to group 1, the other to group 2.
-#' Each of the two lists contains a numeric vector per item, i.e., each list contains as many vectors as items.
-#' Each vector contains the free item-cat. parameters of the respective item. The number of free item-cat.
-#' parameters per item equals the number of categories of the item minus 1.
 #'
 #'@return A list of results.
 #'  \item{power}{Power value for each test.}
@@ -179,8 +179,7 @@
 #' local_dev <-  list (  list(c( 0, 0), c( -1, 0), c( 0, 0),  c( 1, 0), c( 1, 0.5)) ,
 #'                       list(c( 0, 0), c( -1, 0), c( 0, 0),  c( 1, 0), c( 0, -0.5))  )
 #'
-#' res <-  powerPCM(alpha = 0.05, n_total = 200, persons1 = rnorm(10^6),
-#'                   persons2 = rnorm(10^6), local_dev = local_dev)
+#' res <-  powerPCM(n_total = 200, local_dev = local_dev)
 #'
 #'# > res
 #'# $power
@@ -222,16 +221,20 @@
 #'#          persons2 = rnorm(10^6), local_dev = local_dev)
 #' }
 
-powerPCM <- function(alpha = 0.05, n_total, persons1 = rnorm(10^6), persons2 = rnorm(10^6), local_dev){
+powerPCM <- function(n_total,
+                     local_dev,
+                     alpha = 0.05,
+                     persons1 = rnorm(10^6),
+                     persons2 = rnorm(10^6)) {
 
   subfunc <- function(stats) {
-    e <- stats/(sum(t1)+sum(t2))
-    nc <- e * n_total * ((sum(t1)+sum(t2)) / (nrow(y1)+nrow(y2)))
-    f <- function(nc){pchisq(qchisq(1-alpha, df), df, nc)}
+    e <- stats/(sum(t1) + sum(t2))
+    nc <- e * n_total * ((sum(t1) + sum(t2)) / (nrow(y1) + nrow(y2)))
+    f <- function(nc){pchisq(qchisq(1 - alpha, df), df, nc)}
     beta <- f(nc)
     # se <- sqrt((2 * df + 4 * (stats-df)) * (1/((sum(t1)+sum(t2))))^2 * (numDeriv::grad(f, nc) * n_total * ((sum(t1)+sum(t2)) / (nrow(y1)+nrow(y2))))^2)
-    se <- sqrt((2*df + 4*stats) * (1/((sum(t1)+sum(t2))))^2 *
-                 (numDeriv::grad(f, nc) * n_total * ((sum(t1)+sum(t2)) / (nrow(y1)+nrow(y2))))^2)
+    se <- sqrt((2*df + 4*stats) * (1/((sum(t1) + sum(t2))))^2 *
+                 (numDeriv::grad(f, nc) * n_total * ((sum(t1) + sum(t2)) / (nrow(y1) + nrow(y2))))^2)
     power <- 1 - beta
     return(list('power' = round(power, digits = 3),
                 'MC error of power' = round(se, digits = 3),
@@ -239,7 +242,7 @@ powerPCM <- function(alpha = 0.05, n_total, persons1 = rnorm(10^6), persons2 = r
                 'noncentrality parameter' = round(nc, digits = 3) ))
   }
 
-  call<-match.call()
+  call <- match.call()
   # thetas for rmvordlogis() for group 1 and group 2
   # a list with numeric vector elements, with free item-category parameters
   # last the discrimination parameter set to 1.
@@ -260,19 +263,19 @@ powerPCM <- function(alpha = 0.05, n_total, persons1 = rnorm(10^6), persons2 = r
   r2 <- psychotools::pcmodel(y2)
   r3 <- psychotools::pcmodel(rbind(y1,y2))
 
-  t1 <- table(factor(rowSums(y1),levels=1:df))
-  t2 <- table(factor(rowSums(y2),levels=1:df))
+  t1 <- table(factor(rowSums(y1),levels = 1:df))
+  t2 <- table(factor(rowSums(y2),levels = 1:df))
 
-  vstats <- do.call(c, invar_test_obj(r1=r1, r2=r2, r3=r3, model = "PCM"))
+  vstats <- do.call(c, invar_test_obj(r1 = r1, r2 = r2, r3 = r3, model = "PCM"))
 
   res <- lapply(vstats, subfunc)
 
   results <- list(  'power' = unlist(do.call(cbind, res)[1,]),
                     'MC error of power' = unlist(do.call(cbind, res)[2,]),
                     'global deviation' = unlist(do.call(cbind, res)[3,]),
-                    'local deviation' = round(rbind("group1"=r1$coefficients, "group2"= r2$coefficients), digits = 3),
-                    'person score distribution in group 1' = round(t1/sum(t1), digits=3),
-                    'person score distribution in group 2' = round(t2/sum(t2), digits=3),
+                    'local deviation' = round(rbind("group1" = r1$coefficients, "group2" = r2$coefficients), digits = 3),
+                    'person score distribution in group 1' = round(t1/sum(t1), digits = 3),
+                    'person score distribution in group 2' = round(t2/sum(t2), digits = 3),
                     'degrees of freedom' = df,
                     'noncentrality parameter' = unlist(do.call(cbind, res)[4,]),
                     "call" = call)
