@@ -15,7 +15,7 @@
 # where one assumes all items presented to all persons.
 #
 # Licensed under the GNU General Public License Version 3 (June 2007)
-# copyright (c) 2021, Last Modified 25/10/2021
+# copyright (c) 2021, Last Modified 2/9/2024
 ######################################################################
 #' Sample size planning for tests of invariance of item-category parameters between two groups of persons in partial credit model
 #'
@@ -110,6 +110,10 @@
 #'quantify the random error of the suggested Monte Carlo computation procedure. It is called Monte Carlo
 #'error of informative sample size.
 #'
+#' @param local_dev A list consisting of two lists. One list refers to group 1, the other to group 2. Each of the two lists
+#' contains a numerical vector per item, i.e., each list contains as many vectors as items. Each vector contains the free
+#' item-cat. parameters of the respective item. The number of free item-cat. parameters per item equals the number of
+#' categories of the item minus 1.
 #' @param alpha Probability of the error of first kind.
 #' @param beta Probability of the error of second kind.
 #' @param persons1 A vector of person parameters for group 1 (drawn from a specified distribution). By default \eqn{10^6}
@@ -118,10 +122,6 @@
 #' @param persons2 A vector of person parameters for group 2 (drawn from a specified distribution). By default \eqn{10^6}
 #' parameters are drawn at random from the standard normal distribution. The larger this number the more accurate are
 #' the computations. See Details.
-#' @param local_dev A list consisting of two lists. One list refers to group 1, the other to group 2. Each of the two lists
-#' contains a numerical vector per item, i.e., each list contains as many vectors as items. Each vector contains the free
-#' item-cat. parameters of the respective item. The number of free item-cat. parameters per item equals the number of
-#' categories of the item minus 1.
 #'
 #'@return A list of results.
 #'  \item{informative sample size}{Informative sample size for each test, omitting persons with min. and max score.}
@@ -218,11 +218,14 @@
 #'#            persons2 = rnorm(10^6), local_dev = local_dev)
 #' }
 
-sa_sizePCM <- function(alpha = 0.05, beta = 0.05, persons1 = rnorm(10^6),
-                       persons2 = rnorm(10^6), local_dev){
+sa_sizePCM <- function(local_dev,
+                       alpha = 0.05,
+                       beta = 0.05,
+                       persons1 = rnorm(10^6),
+                       persons2 = rnorm(10^6)) {
 
   subfunc <- function(stats) {
-    e <- stats/(sum(t1)+sum(t2))
+    e <- stats/(sum(t1) + sum(t2))
     n <- ceiling(lambda0 / e)
     se <- sqrt((2*df + 4*stats) * lambda0^2 * (sum(t1) + sum(t2))^2 * (stats)^-4)
     n1 <- ceiling((n/2)/(sum(t1)/nrow(y1)))
@@ -234,7 +237,7 @@ sa_sizePCM <- function(alpha = 0.05, beta = 0.05, persons1 = rnorm(10^6),
                 'total sample size in group 2' = n2 ))
   }
 
-  call<-match.call()
+  call <- match.call()
 
   # thetas for rmvordlogis() for group 1 and group 2
   # a list with numeric vector elements, with free item-category parameters,
@@ -253,26 +256,26 @@ sa_sizePCM <- function(alpha = 0.05, beta = 0.05, persons1 = rnorm(10^6),
 
   df <- length(unlist(local_dev[[1]])) - length((local_dev[[1]])) - 1
 
-  func <- function (x) {beta - pchisq(qchisq(1-alpha, df), df, ncp = x)}
-  lambda0 <- uniroot(f = func, interval = c(0,10^3), tol=.Machine$double.eps^0.5)$root
+  func <- function(x) {beta - pchisq(qchisq(1 - alpha, df), df, ncp = x)}
+  lambda0 <- uniroot(f = func, interval = c(0,10^3), tol = .Machine$double.eps^0.5)$root
 
   r1 <- psychotools::pcmodel(y1)
   r2 <- psychotools::pcmodel(y2)
   r3 <- psychotools::pcmodel(rbind(y1,y2))
 
-  t1 <- table(factor(rowSums(y1),levels=1:df))
-  t2 <- table(factor(rowSums(y2),levels=1:df))
+  t1 <- table(factor(rowSums(y1),levels = 1:df))
+  t2 <- table(factor(rowSums(y2),levels = 1:df))
 
-  vstats <- do.call(c, invar_test_obj(r1=r1, r2=r2, r3=r3, model = "PCM"))
+  vstats <- do.call(c, invar_test_obj(r1 = r1, r2 = r2, r3 = r3, model = "PCM"))
 
   res <- lapply(vstats, subfunc)
 
   results <- list(  'informative sample size' = unlist(do.call(cbind, res)[1,]),
                     'MC error of sample size' = unlist(do.call(cbind, res)[2,]),
                     'global deviation' = unlist(do.call(cbind, res)[3,]),
-                    'local deviation' = round(rbind("group1"=r1$coefficients, "group2"= r2$coefficients), digits = 3),
-                    'person score distribution in group 1' = round(t1/sum(t1), digits=3),
-                    'person score distribution in group 2' = round(t2/sum(t2), digits=3),
+                    'local deviation' = round(rbind("group1" = r1$coefficients, "group2" = r2$coefficients), digits = 3),
+                    'person score distribution in group 1' = round(t1/sum(t1), digits = 3),
+                    'person score distribution in group 2' = round(t2/sum(t2), digits = 3),
                     'degrees of freedom' = df,
                     'noncentrality parameter' = round(lambda0, digits = 3),
                     'total sample size in group 1' = unlist(do.call(cbind, res)[4,]),
